/* #####################################################################
 * #                        REFLEXIVE FRAMEWORK                        #
 * #                        ___________________                        #
 * #                                                                   #
 * # Reflexive Framework, Copyright (C) 2007 Andries Inze              #
 * #                                                                   #
 * # This program is free software; you can redistribute it and/or     #
 * # modify it under the terms of the GNU General Public License       #
 * # as published by the Free Software Foundation; either version 2    #
 * # of the License, or (at your option) any later version.            #
 * #                                                                   #
 * # This program is distributed in the hope that it will be useful,   #
 * # but WITHOUT ANY WARRANTY; without even the implied warranty of    #
 * # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     #
 * # GNU General Public License for more details.                      #
 * #                                                                   #
 * # You should have received a copy of the GNU General Public License #
 * # along with this program; if not, write to the Free Software       #
 * # Foundation, Inc., 59 Temple Place - Suite 330, Boston,            #
 * # MA  02111-1307, USA.                                              #
 * #                                                                   #
 * #####################################################################
 */
package org.reflexiveframework.internal.common;

import org.apache.commons.lang.Validate;

/**
 * Common static utility class.
 * To be used internally only
 * 
 * @author Andries Inze
 *
 */
public final class ReflexiveUtils {

    /**
     * Utility methods need private constructors.
     */
    private ReflexiveUtils() {
        
    }
    
    /**
     * Converts a getter into the property name.
     * e.g.
     * 'getNickName' will be converted into 'nickName'
     * 
     * @param methodName the full methodName
     * @return the propertyName
     */
    public static String convertMethodNameToPropertyName(
            final String methodName) {
    	Validate.notNull(methodName, "The methodName can not be null");
    	Validate.isTrue(methodName.startsWith("get") 
    			|| methodName.startsWith("is"), "Only getters are supported");
    	
    	StringBuilder sb = new StringBuilder(methodName);
    	if (methodName.startsWith("get")) {
    		sb.delete(0, 3);
    	} else {
    		sb.delete(0, 2);
    	}
    	sb.setCharAt(0, Character.toLowerCase(sb.charAt(0)));
    	return sb.toString();    		
    	
    }

    /**
     * @return
     */
    public static String createRandomString() {
        return "" + System.currentTimeMillis();
    }

	public static String makeNestedPath(String... propertyNames) {
		StringBuilder sb = new StringBuilder();
		
		for (int i = 0; i < propertyNames.length; i++) {
			sb.append(propertyNames[i]);
			if(i < propertyNames.length-1) {
				sb.append(".");
			}
		}
		
		return sb.toString();
	}
}
